@@ -4,7 +4,9 @@ format and encapsulate some generic mechanisms for producing
 things like spike timing autocorrelograms, power spectrum calculation and so on
 """
 import numpy as np
+import numpy.typing as npt
 from scipy import signal
+from scipy.interpolate import griddata
 
 
 class EventsGeneric(object):
@@ -16,8 +18,8 @@ class EventsGeneric(object):
     Idea is to present a generic interface to other classes/ functions
     regardless of how the events were created.
 
-    As a starting point lets base this on the dacq2py STM class which extends
-    dict() and dacq2py.axonaIO.IO().
+    As a starting point lets base this on the axona STM class which extends
+    dict() and axona.axonaIO.IO().
 
     For a fairly complete description of the nomenclature used for the
     timulation / event parameters see the STM property of the
@@ -63,23 +65,43 @@ class EventsGeneric(object):
     the various types of open-ephys recordings using the Arduino-based plugin
     (called StimControl - see https://github.com/rhayman/StimControl)
     """
+
     def __init__(self):
-        level_one_keys = ['on', 'trial_date', 'trial_time', 'experimenter',
-                          'comments', 'duration', 'sw_version', 'num_chans',
-                          'timebase', 'bytes_per_timestamp', 'data_format',
-                          'num_stm_samples', 'posSampRate', 'eegSampRate',
-                          'egfSampRate', 'off', 'stim_params']
-        level_two_keys = ['Phase_1', 'Phase_2', 'Phase_3']
-        level_three_keys = ['startTime', 'duration', 'name', 'pulseWidth',
-                            'pulseRatio', 'pulsePause']
+        level_one_keys = [
+            "on",
+            "trial_date",
+            "trial_time",
+            "experimenter",
+            "comments",
+            "duration",
+            "sw_version",
+            "num_chans",
+            "timebase",
+            "bytes_per_timestamp",
+            "data_format",
+            "num_stm_samples",
+            "posSampRate",
+            "eegSampRate",
+            "egfSampRate",
+            "off",
+            "stim_params",
+        ]
+        level_two_keys = ["Phase_1", "Phase_2", "Phase_3"]
+        level_three_keys = [
+            "startTime",
+            "duration",
+            "name",
+            "pulseWidth",
+            "pulseRatio",
+            "pulsePause",
+        ]
 
         from collections import OrderedDict
-        self._event_dict = dict.fromkeys(
-            level_one_keys)
-        self._event_dict['stim_params'] = OrderedDict.fromkeys(
-            level_two_keys)
-        for k in self._event_dict['stim_params'].keys():
-            self._event_dict['stim_params'][k] = dict.fromkeys(
+
+        self._event_dict = dict.fromkeys(level_one_keys)
+        self._event_dict["stim_params"] = OrderedDict.fromkeys(level_two_keys)
+        for k in self._event_dict["stim_params"].keys():
+            self._event_dict["stim_params"][k] = dict.fromkeys(
                 level_three_keys)
 
 
@@ -94,6 +116,7 @@ class EEGCalcsGeneric(object):
     fs  : float
         The sample rate
     """
+
     def __init__(self, sig, fs):
         self.sig = sig
         self.fs = fs
@@ -120,7 +143,10 @@ class EEGCalcsGeneric(object):
         return np.log2(val + 1)
 
     def butterFilter(
-            self, low: float, high: float, order: int = 5) -> np.ndarray:
+                     self,
+                     low: float,
+                     high: float,
+                     order: int = 5) -> np.ndarray:
         """
         Filters self.sig with a butterworth filter with a bandpass filter
         defined by low and high
@@ -145,7 +171,7 @@ class EEGCalcsGeneric(object):
         nyqlim = self.fs / 2
         lowcut = low / nyqlim
         highcut = high / nyqlim
-        b, a = signal.butter(order, [lowcut, highcut], btype='band')
+        b, a = signal.butter(order, [lowcut, highcut], btype="band")
         return signal.filtfilt(b, a, self.sig)
 
     def calcEEGPowerSpectrum(self, **kwargs):
@@ -173,23 +199,25 @@ class EEGCalcsGeneric(object):
         nqlim = self.fs / 2
         origlen = len(self.sig)
 
-        if 'pad2pow' not in kwargs:
+        if "pad2pow" not in kwargs:
             fftlen = int(np.power(2, self._nextpow2(origlen)))
         else:
-            pad2pow = kwargs.pop('pad2pow')
+            pad2pow = kwargs.pop("pad2pow")
             fftlen = int(np.power(2, pad2pow))
 
         freqs, power = signal.periodogram(
-            self.sig, self.fs, return_onesided=True, nfft=fftlen)
-        ffthalflen = fftlen / 2+1
-        binsperhz = (ffthalflen-1) / nqlim
+            self.sig, self.fs, return_onesided=True, nfft=fftlen
+        )
+        ffthalflen = fftlen / 2 + 1
+        binsperhz = (ffthalflen - 1) / nqlim
         kernelsigma = self.smthKernelSigma * binsperhz
         smthkernelsigma = 2 * int(4.0 * kernelsigma + 0.5) + 1
         gausswin = signal.gaussian(smthkernelsigma, kernelsigma)
-        sm_power = signal.fftconvolve(power, gausswin, 'same')
+        sm_power = signal.fftconvolve(power, gausswin, "same")
         sm_power = sm_power / np.sqrt(len(sm_power))
         spectrummaskband = np.logical_and(
-            freqs > self.thetaRange[0], freqs < self.thetaRange[1])
+            freqs > self.thetaRange[0], freqs < self.thetaRange[1]
+        )
         bandmaxpower = np.max(sm_power[spectrummaskband])
         maxbininband = np.argmax(sm_power[spectrummaskband])
         bandfreqs = freqs[spectrummaskband]
@@ -201,71 +229,6 @@ class EEGCalcsGeneric(object):
         self.freqatbandmaxpower = freqatbandmaxpower
         return freqs, power, sm_power, bandmaxpower, freqatbandmaxpower
 
-    '''
-    def plotEventEEG(
-            self, event_ts, event_window=(-0.05, 0.1), stim_width=0.01,
-            sample_rate=3e4):
-        """
-        Plots the mean eeg +- std. dev centred on event timestamps
-
-        Parameters
-        ----------
-        event_ts : array_like
-            The event timestamps in seconds
-        event_window : 2-tuple, default = (-0.05, 0.1)
-            The pre- and post-stimulus window to examine. In seconds.
-            Defaults to the previous 50ms and the subsequent 100ms
-        stim_width : float
-            The duration of the stimulus. Used for plotting
-        sample_rate : float
-            The sample rate of the events
-
-        """
-        # bandpass filter the raw data first
-        from scipy import signal
-        # nyq = sample_rate / 2
-        highlim = 500
-        if highlim >= sample_rate/2:
-            highlim = (sample_rate-1)/2
-        b, a = signal.butter(5, highlim, fs=sample_rate, btype='lowpass')
-        sig = signal.filtfilt(b, a, self.sig)
-
-        event_idx = np.round(event_ts*sample_rate).astype(int)
-        event_window = np.array(event_window)
-
-        max_samples = np.ptp(event_window*sample_rate).astype(int)
-        num_events = len(event_ts)
-        eeg_array = np.zeros([num_events, max_samples])
-        st = int(event_window[0]*sample_rate)
-        en = int(event_window[1]*sample_rate)
-        for i, eeg_idx in enumerate(event_idx):
-            eeg_array[i, :] = sig[eeg_idx+st:eeg_idx+en]
-        mn = np.mean(eeg_array, 0)
-        se = np.std(eeg_array, 0) / np.sqrt(num_events)
-        import matplotlib.pylab as plt
-        # from mpl_toolkits.axes_grid1 import make_axes_locatable
-        import matplotlib.transforms as transforms
-        from matplotlib.patches import Rectangle
-        fig = plt.figure()
-        ax = fig.add_subplot(111)
-        ax.errorbar(
-            np.linspace(
-                event_window[0], event_window[1], len(mn)),
-            mn,
-            yerr=se, rasterized=False)
-        ax.set_xlim(event_window)
-        axTrans = transforms.blended_transform_factory(
-            ax.transData, ax.transAxes)
-        ax.add_patch(
-            Rectangle(
-                (0, 0), width=stim_width, height=1,
-                transform=axTrans,
-                color=[1, 1, 0], alpha=0.5))
-        ax.set_ylabel(r'LFP ($\mu$V)')
-        ax.set_xlabel('Time(s)')
-        return fig
-    '''
-
     def ifftFilter(self, sig, freqs, fs=250):
         """
         Calculates the dft of signal and filters out the frequencies in
@@ -289,15 +252,15 @@ class EEGCalcsGeneric(object):
         # from scipy import signal
         nyq = fs / 2.0
         fftRes = np.fft.fft(sig)
-        f = nyq * np.linspace(0, 1, int(len(fftRes)/2))
+        f = nyq * np.linspace(0, 1, int(len(fftRes) / 2))
         f = np.concatenate([f, f - nyq])
 
         band = 0.0625
         idx = np.zeros([len(freqs), len(f)]).astype(bool)
 
         for i, freq in enumerate(freqs):
-            idx[i, :] = np.logical_and(np.abs(f) < freq+band, np.abs(f) >
-                                       freq-band)
+            idx[i, :] = np.logical_and(
+                np.abs(f) < freq + band, np.abs(f) > freq - band)
 
         pollutedIdx = np.sum(idx, 0)
         fftRes[pollutedIdx] = np.mean(fftRes)
@@ -319,6 +282,10 @@ class PosCalcsGeneric(object):
         Whether everything is converted into cms or not
     jumpmax : int
         Jumps in position (pixel coords) greater than this are bad
+    **kwargs:
+        a dict[str, float] called 'tracker_params' is used to limit the
+        range of valid xy positions - 'bad' positions are masked out
+        and interpolated over
 
     Notes
     -----
@@ -326,27 +293,102 @@ class PosCalcsGeneric(object):
     class is initialised - that mask is then modified through various
     functions (postprocesspos being the main one).
     """
-    def __init__(self, x, y, ppm, cm=True, jumpmax=100):
+
+    def __init__(
+        self,
+        x: npt.ArrayLike,
+        y: npt.ArrayLike,
+        ppm: float,
+        cm: bool = True,
+        jumpmax: float = 100,
+        **kwargs,
+    ):
         assert np.shape(x) == np.shape(y)
-        self.orig_xy = np.ma.MaskedArray([x, y])
-        self.dir = np.ma.MaskedArray(np.zeros_like(x))
-        self.speed = None
-        self.ppm = ppm
+        self.orig_xy: np.ma.MaskedArray = np.ma.MaskedArray([x, y])
+        self._xy = None
+        self._xyTS = None
+        self._dir = np.ma.MaskedArray(np.zeros_like(x))
+        self._speed = None
+        self._ppm = ppm
         self.cm = cm
-        self.jumpmax = jumpmax
+        self._jumpmax = jumpmax
         self.nleds = np.ndim(x)
         self.npos = len(x)
-        self.tracker_params = None
-        self.sample_rate = 30
+        if "tracker_params" in kwargs:
+            self.tracker_params = kwargs["tracker_params"]
+        else:
+            self.tracker_params = {}
+        self._sample_rate = 30
 
-    def postprocesspos(self, tracker_params={}, **kwargs) -> tuple:
+    @property
+    def xy(self) -> np.ma.MaskedArray:
+        return self._xy
+
+    @xy.setter
+    def xy(self, value) -> None:
+        self._xy: np.ma.MaskedArray = value
+
+    @property
+    def xyTS(self):
+        return self._xyTS
+
+    @xyTS.setter
+    def xyTS(self, val):
+        self._xyTS = val
+
+    @property
+    def dir(self) -> np.ma.MaskedArray:
+        return self._dir
+
+    @dir.setter
+    def dir(self, value) -> None:
+        self._dir: np.ma.MaskedArray = value
+
+    @property
+    def ppm(self) -> float:
+        return self._ppm
+
+    @ppm.setter
+    def ppm(self, value) -> None:
+        self._ppm: float = value
+        self.postprocesspos(self.tracker_params)
+
+    @property
+    def jumpmax(self):
+        return self._jumpmax
+
+    @jumpmax.setter
+    def jumpmax(self, val):
+        self._jumpmax = val
+        self.postprocesspos(self.tracker_params)
+
+    @property
+    def speed(self):
+        return self._speed
+
+    @speed.setter
+    def speed(self, value):
+        self._speed = value
+
+    @property
+    def sample_rate(self):
+        return self._sample_rate
+
+    @sample_rate.setter
+    def sample_rate(self, val):
+        self._sample_rate = val
+
+    def postprocesspos(
+                       self,
+                       tracker_params: "dict[str, float]" = {},
+                       **kwargs) -> None:
         """
         Post-process position data
 
         Parameters
         ----------
         tracker_params : dict
-            Same dict as created in OEKiloPhy.Settings.parse
+            Same dict as created in OESettings.Settings.parse
             (from module openephys2py)
 
         Returns
@@ -368,45 +410,54 @@ class PosCalcsGeneric(object):
         y_zero = xy[1, :] < 0
         xy[:, np.logical_or(x_zero, y_zero)] = np.ma.masked
 
-        self.tracker_params = tracker_params
-        if 'LeftBorder' in tracker_params:
-            min_x = tracker_params['LeftBorder']
+        self.tracker_params: dict[str, float] = tracker_params
+        if "AxonaBadValue" in tracker_params:
+            bad_val = tracker_params["AxonaBadValue"]
+            xy = np.ma.masked_equal(xy, bad_val)
+        if "LeftBorder" in tracker_params:
+            min_x = tracker_params["LeftBorder"]
             xy[:, xy[0, :] <= min_x] = np.ma.masked
-        if 'TopBorder' in tracker_params:
-            min_y = tracker_params['TopBorder']  # y origin at top
+        if "TopBorder" in tracker_params:
+            min_y = tracker_params["TopBorder"]  # y origin at top
             xy[:, xy[1, :] <= min_y] = np.ma.masked
-        if 'RightBorder' in tracker_params:
-            max_x = tracker_params['RightBorder']
+        if "RightBorder" in tracker_params:
+            max_x = tracker_params["RightBorder"]
             xy[:, xy[0, :] >= max_x] = np.ma.masked
-        if 'BottomBorder' in tracker_params:
-            max_y = tracker_params['BottomBorder']
+        if "BottomBorder" in tracker_params:
+            max_y = tracker_params["BottomBorder"]
             xy[:, xy[1, :] >= max_y] = np.ma.masked
-        if 'SampleRate' in tracker_params:
-            self.sample_rate = int(tracker_params['SampleRate'])
+        if "SampleRate" in tracker_params:
+            self.sample_rate = int(tracker_params["SampleRate"])
         else:
             self.sample_rate = 30
-        
-        if self.cm:
-            xy = xy / ( self.ppm / 100. )
 
-        # xy = xy.T
+        if self.cm:
+            xy = xy / (self._ppm / 100.0)
+
         xy = self.speedfilter(xy)
-        xy = self.interpnans(xy)  # ADJUST THIS SO NP.MASKED ARE INTERPOLATED
+        xy = self.interpnans(xy)
         xy = self.smoothPos(xy)
         self.calcSpeed(xy)
-        hdir = self.calcHeadDirection(xy)
-        self.xy = xy
-        self.dir = hdir
-        return xy, hdir
+        self._xy = xy
+        self._dir = self.calcHeadDirection(xy)
 
-    def calcHeadDirection(self, xy: np.ma.MaskedArray):
+    def calcHeadDirection(self, xy: np.ma.MaskedArray) -> np.ma.MaskedArray:
         import math
-        pos2 = np.arange(0, self.npos-1)
+
+        pos2 = np.arange(0, self.npos - 1)
         xy_f = xy.astype(float)
         self.dir[pos2] = np.mod(
-            ((180/math.pi) * (np.arctan2(
-                -xy_f[1, pos2+1] + xy_f[1, pos2], +xy_f[0, pos2+1]-xy_f[
-                    0, pos2]))), 360)
+            (
+                (180 / math.pi)
+                * (
+                    np.arctan2(
+                        -xy_f[1, pos2 + 1] + xy_f[1, pos2],
+                        +xy_f[0, pos2 + 1] - xy_f[0, pos2],
+                    )
+                )
+            ),
+            360,
+        )
         self.dir[-1] = self.dir[-2]
         return self.dir
 
@@ -425,36 +476,36 @@ class PosCalcsGeneric(object):
             The xy data with speeds > self.jumpmax masked
         """
 
-        disp = np.hypot(xy[0], xy[1])
-        disp = np.diff(disp, axis=0)
-        disp = np.insert(disp, -1, 0)
-        jumps = np.abs(disp) > self.jumpmax
-        x = xy[0]
-        y = xy[1]
-        x = np.ma.masked_where(jumps, x)
-        y = np.ma.masked_where(jumps, y)
-        if getattr(self, 'mask_min_values', True):
-            x = np.ma.masked_equal(x, np.min(x))
-            y = np.ma.masked_equal(y, np.min(y))
+        disp: np.ma.MaskedArray = np.hypot(xy[0], xy[1])
+        disp: np.ma.MaskedArray = np.diff(disp, axis=0)
+        disp: np.ma.MaskedArray = np.insert(disp, -1, 0)
+        if self.cm:
+            jumpmax: float = self.ppm / self.jumpmax
+        else:
+            jumpmax: float = self.jumpmax
+        jumps: np.ma.MaskedArray = np.abs(disp) > jumpmax
+        x: np.ma.MaskedArray = xy[0]
+        y: np.ma.MaskedArray = xy[1]
+        x: np.ma.MaskedArray = np.ma.masked_where(jumps, x)
+        y: np.ma.MaskedArray = np.ma.masked_where(jumps, y)
+        if getattr(self, "mask_min_values", True):
+            x: np.ma.MaskedArray = np.ma.masked_equal(x, np.min(x))
+            y: np.ma.MaskedArray = np.ma.masked_equal(y, np.min(y))
         xy = np.ma.array([x, y])
         return xy
 
-    def interpnans(self, xy: np.ma.MaskedArray):
-        for i in range(0, np.shape(xy)[0], 2):
-            missing = xy.mask.any(axis=0)
-            ok = np.logical_not(missing)
-            ok_idx = np.ravel(np.nonzero(np.ravel(ok))[0])
-            missing_idx = np.ravel(np.nonzero(np.ravel(missing))[0])
-            if np.logical_and(len(missing_idx) > 0, len(ok_idx) > 0):
-                good_data = np.ma.ravel(xy.data[i, ok_idx])
-                good_data1 = np.ma.ravel(xy.data[i+1, ok_idx])
-                xy.data[i, missing_idx] = np.interp(
-                    missing_idx, ok_idx, good_data)
-                xy.data[i+1, missing_idx] = np.interp(
-                    missing_idx, ok_idx, good_data1)
-        print("{} bad positions were interpolated over".format(
-            len(missing_idx)))
-        return xy
+    def interpnans(self, xy: np.ma.MaskedArray) -> np.ma.MaskedArray:
+        n_masked: int = np.count_nonzero(xy.mask)
+        if n_masked > 2:
+            xm: np.ma.MaskedArray = xy[0]
+            ym: np.ma.MaskedArray = xy[1]
+            idx: np.ndarray = np.arange(0, len(xm))
+            xi = griddata(idx[~xm.mask], xm[~xm.mask], idx, method="linear")
+            yi = griddata(idx[~ym.mask], ym[~ym.mask], idx, method="linear")
+            print(f"Interpolated over {n_masked} bad values")
+            return np.ma.MaskedArray([xi, yi])
+        else:
+            return xy
 
     def smoothPos(self, xy: np.ma.MaskedArray):
         """
@@ -474,10 +525,11 @@ class PosCalcsGeneric(object):
         y = xy[1, :].astype(np.float64)
 
         from ephysiopy.common.utils import smooth
+
         # TODO: calculate window_len from pos sampling rate
         # 11 is roughly equal to 400ms at 30Hz (window_len needs to be odd)
-        sm_x = smooth(x, window_len=11, window='flat')
-        sm_y = smooth(y, window_len=11, window='flat')
+        sm_x = smooth(x, window_len=11, window="flat")
+        sm_y = smooth(y, window_len=11, window="flat")
         return np.ma.masked_array([sm_x, sm_y])
 
     def calcSpeed(self, xy: np.ma.MaskedArray):
@@ -497,9 +549,8 @@ class PosCalcsGeneric(object):
         self.speed = np.append(speed, speed[-1])
         if self.cm:
             self.speed = self.speed * self.sample_rate
-        return self.speed
 
-    def upsamplePos(self, xy: np.ma.MaskedArray, upsample_rate: int=50):
+    def upsamplePos(self, xy: np.ma.MaskedArray, upsample_rate: int = 50):
         """
         Upsamples position data from 30 to upsample_rate
 
@@ -523,18 +574,19 @@ class PosCalcsGeneric(object):
         into Axona format 50Hz data
         """
         from scipy import signal
+
         denom = np.gcd(upsample_rate, 30)
 
         new_x = signal.resample_poly(
-            xy[0, :], upsample_rate/denom, 30/denom)
+            xy[0, :], upsample_rate / denom, 30 / denom)
         new_y = signal.resample_poly(
-            xy[1, :], upsample_rate/denom, 30/denom)
+            xy[1, :], upsample_rate / denom, 30 / denom)
         return np.array([new_x, new_y])
 
-    def filterPos(self, filter_dict: dict = {}):
-        '''
-        Filters data based on key/ values in filter_dict
-        Meant to replicate a similar function in dacq2py_util.Trial
+    def filterPos(self, filt: dict = {}):
+        """
+        Filters data based on key/ values in filt
+        Meant to replicate a similar function in axona_util.Trial
         called filterPos
 
         Parameters
@@ -556,57 +608,62 @@ class PosCalcsGeneric(object):
         --------
         pos_index_to_keep : ndarray
             The position indices that should be kept
-        '''
-        if filter_dict is None:
+        """
+        if filt is None:
             self.xy.mask = False
             self.dir.mask = False
             self.speed.mask = False
             return False
-        bool_arr = np.ones(shape=(len(filter_dict), self.npos), dtype=np.bool)
-        for idx, key in enumerate(filter_dict):
-            if isinstance(filter_dict[key], str):
-                if len(filter_dict[key]) == 1 and 'dir' in key:
-                    if 'w' in filter_dict[key]:
-                        filter_dict[key] = (135, 225)
-                    elif 'e' in filter_dict[key]:
-                        filter_dict[key] = (315, 45)
-                    elif 's' in filter_dict[key]:
-                        filter_dict[key] = (225, 315)
-                    elif 'n' in filter_dict[key]:
-                        filter_dict[key] = (45, 135)
+        bool_arr = np.ones(shape=(len(filt), self.npos), dtype=bool)
+        for idx, key in enumerate(filt):
+            if isinstance(filt[key], str):
+                if len(filt[key]) == 1 and "dir" in key:
+                    if "w" in filt[key]:
+                        filt[key] = (135, 225)
+                    elif "e" in filt[key]:
+                        filt[key] = (315, 45)
+                    elif "s" in filt[key]:
+                        filt[key] = (225, 315)
+                    elif "n" in filt[key]:
+                        filt[key] = (45, 135)
                 else:
                     raise ValueError("filter must contain a key / value pair")
-            if 'speed' in key:
-                if filter_dict[key][0] > filter_dict[key][1]:
-                    raise ValueError("First value must be less \
-                        than the second one")
+            if "speed" in key:
+                if filt[key][0] > filt[key][1]:
+                    raise ValueError(
+                        "First value must be less \
+                        than the second one"
+                    )
                 else:
                     bool_arr[idx, :] = np.logical_and(
-                        self.speed > filter_dict[key][0],
-                        self.speed < filter_dict[key][1])
-            elif 'dir' in key:
-                if filter_dict[key][0] < filter_dict[key][1]:
+                        self.speed > filt[key][0],
+                        self.speed < filt[key][1],
+                    )
+            elif "dir" in key:
+                if filt[key][0] < filt[key][1]:
                     bool_arr[idx, :] = np.logical_and(
-                        self.dir > filter_dict[key][0],
-                        self.dir < filter_dict[key][1])
+                        self.dir > filt[key][0], self.dir < filt[key][1]
+                    )
                 else:
                     bool_arr[idx, :] = np.logical_or(
-                        self.dir > filter_dict[key][0],
-                        self.dir < filter_dict[key][1])
-            elif 'xrange' in key:
+                        self.dir > filt[key][0], self.dir < filt[key][1]
+                    )
+            elif "xrange" in key:
                 bool_arr[idx, :] = np.logical_and(
-                    self.xy[0, :] > filter_dict[key][0],
-                    self.xy[0, :] < filter_dict[key][1])
-            elif 'yrange' in key:
+                    self.xy[0, :] > filt[key][0],
+                    self.xy[0, :] < filt[key][1],
+                )
+            elif "yrange" in key:
                 bool_arr[idx, :] = np.logical_and(
-                    self.xy[1, :] > filter_dict[key][0],
-                    self.xy[1, :] < filter_dict[key][1])
-            elif 'time' in key:
+                    self.xy[1, :] > filt[key][0],
+                    self.xy[1, :] < filt[key][1],
+                )
+            elif "time" in key:
                 # takes the form of 'from' - 'to' times in SECONDS
                 # such that only pos's between these ranges are KEPT
-                for i in filter_dict[key]:
-                    bool_arr[
-                        idx, i*self.sample_rate:i*self.sample_rate] = False
+                for i in filt[key]:
+                    bool_arr[idx, i * self.sample_rate: i *
+                             self.sample_rate] = False
                 bool_arr = ~bool_arr
             else:
                 raise KeyError("Unrecognised key")
