@@ -6,17 +6,20 @@ try:
     import xml.etree.cElementTree as ET
 except ImportError:
     import xml.etree.ElementTree as ET
-from collections import OrderedDict, defaultdict
+
+import xml
 from abc import ABC
+from collections import OrderedDict
 from dataclasses import dataclass, field
 from typing import Callable, List
-import xml
+
 
 @dataclass
 class Channel(object):
     """
     Documents the information attached to each channel
     """
+
     name: str = field(default_factory=str)
     _number: int = field(default_factory=int)
     _gain: float = field(default_factory=float)
@@ -48,7 +51,7 @@ class Channel(object):
 
     @param.setter
     def param(self, value: str) -> None:
-        if value == '1':
+        if value == "1":
             self._param = True
         else:
             self._param = False
@@ -59,7 +62,7 @@ class Channel(object):
 
     @record.setter
     def record(self, value: str) -> None:
-        if value == '1':
+        if value == "1":
             self._record = True
         else:
             self._record = False
@@ -70,7 +73,7 @@ class Channel(object):
 
     @audio.setter
     def audio(self, value: str) -> None:
-        if value == '1':
+        if value == "1":
             self._audio = True
         else:
             self._audio = False
@@ -92,22 +95,52 @@ class Channel(object):
         self._highcut = int(value)
 
 
+@dataclass
+class Stream():
+    """
+    Documents an OE DatasSream
+    """
+
+    name: str = field(default=None)
+    description: str = field(default=None)
+    sample_rate: int = field(default=None)
+    channel_count: int = field(default=None)
+
+
 @dataclass
 class OEPlugin(ABC):
     """
     Documents an OE plugin
     """
+
     name: str = field(default=None)
     insertionPoint: int = field(default=None)
     pluginName: str = field(default=None)
-    pluginType: int = field(default=None)
-    pluginIndex: int = field(default=None)
+    type: int = field(default=None)
+    index: int = field(default=None)
     libraryName: str = field(default=None)
     libraryVersion: int = field(default=None)
-    NodeId: int = field(default=None)
-    Type: str = field(default=None)
-    isSource: bool = field(default=True)
-    isSink: bool = field(default=False)
+    processorType: int = field(default=None)
+    nodeId: int = field(default=None)
+    channel_count: int = field(default=None)
+    stream: Stream = field(default=None)
+    sample_rate: int = field(default=None)
+
+
+@dataclass
+class RecordNode(OEPlugin):
+    """
+    Documents the RecordNode plugin
+    """
+
+    path: str = field(default=None)
+    engine: str = field(default=None)
+    recordEvents: int = field(default=None)
+    recordSpikes: int = field(default=None)
+    isMainStream: int = field(default=None)
+    sync_line: int = field(default=None)
+    source_node_id: int = field(default=None)
+    recording_state: str = field(default=None)
 
 
 @dataclass
@@ -115,9 +148,9 @@ class RhythmFPGA(OEPlugin):
     """
     Documents the Rhythm FPGA plugin
     """
+
     channel_info: List[Channel] = field(default=None)
-    sample_rate: int = field(default=None)
-        
+
 
 # Identical to the RhythmFPGA class above for now
 @dataclass
@@ -125,8 +158,18 @@ class NeuropixPXI(OEPlugin):
     """
     Documents the Neuropixels-PXI plugin
     """
+
     channel_info: List[Channel] = field(default=None)
-    sample_rate: int = field(default=None)
+
+
+@dataclass
+class AcquisitionBoard(OEPlugin):
+    """
+    Documents the Acquisition Board plugin
+    """
+
+    LowCut: int = field(default=None)
+    HighCut: int = field(default=None)
 
 
 @dataclass
@@ -134,12 +177,11 @@ class BandpassFilter(OEPlugin):
     """
     Documents the Bandpass Filter plugin
     """
-    name = "Filters/Bandpass Filter"
+
+    name = "Bandpass Filter"
     pluginName = "Bandpass Filter"
     pluginType = 1
     libraryName = "Bandpass Filter"
-    isSource = False
-    isSink = False
 
     channels: List[int] = field(default_factory=List)
     lowcuts: List[int] = field(default_factory=List)
@@ -163,6 +205,29 @@ class PosTracker(OEPlugin):
     OverlayPath: bool = field(default=False)
 
 
+@dataclass
+class TrackMe(OEPlugin):
+    """
+    Documents the TrackMe plugin
+    """
+    pass
+
+
+@dataclass
+class StimControl(OEPlugin):
+    """
+    Documents the StimControl plugin
+    """
+    Device: int = field(default=None)
+    Duration: int = field(default=None)
+    Interval: int = field(default=None)
+    Gate: int = field(default=None)
+    Output: int = field(default=None)
+    Start: int = field(default=None)
+    Stop: int = field(default=None)
+    Trigger: int = field(default=None)
+
+
 @dataclass
 class SpikeSorter(OEPlugin):
     pass
@@ -173,6 +238,7 @@ class Electrode(object):
     """
     Documents the ELECTRODE entries in the settings.xml file
     """
+
     nChannels: int = field(default_factory=int)
     id: int = field(default_factory=int)
     subChannels: List[int] = field(default_factory=List)
@@ -182,11 +248,14 @@ class Electrode(object):
     postPeakSamples: int = field(default=32)
 
 
-def recurseNode(node: xml.etree.ElementTree.Element, func: Callable, cls: dataclass):
-    '''
+def recurseNode(
+                node: xml.etree.ElementTree.Element,
+                func: Callable,
+                cls: dataclass):
+    """
     Recursive function that applies func to each node
-    '''
-    if node != None:
+    """
+    if node is not None:
         func(node, cls)
         for item in node:
             recurseNode(item, func, cls)
@@ -194,38 +263,41 @@ def recurseNode(node: xml.etree.ElementTree.Element, func: Callable, cls: datacl
         return
 
 
-def addValuesToDataClass(node: xml.etree.ElementTree.Element, cls: dataclass):
+def addValues2Class(node: xml.etree.ElementTree.Element, cls: dataclass):
     for i in node.items():
         if hasattr(cls, i[0]):
             setattr(cls, i[0], i[1])
-    if hasattr(cls, 'channel_info') and node.tag == 'CHANNEL':
+    if hasattr(cls, "channel_info") and node.tag == "CHANNEL":
         if cls.channel_info is None:
             cls.channel_info = list()
         chan = Channel()
-        recurseNode(node, addValuesToDataClass, chan)
+        recurseNode(node, addValues2Class, chan)
         cls.channel_info.append(chan)
+    if hasattr(cls, "stream") and node.tag == "STREAM":
+        if cls.stream is None:
+            cls.stream = Stream()
+        recurseNode(node, addValues2Class, cls.stream)
+
 
-                
 class OEStructure(object):
     """
     Loads up the structure.oebin file for openephys flat binary
     format recordings
-    
-    self.data is a dict
     """
+
     def __init__(self, pname: str):
-        self.filename = None
-        self.data = None
+        self.filename = []
+        self.data = []
         import os
+        import json
+
         for d, _, f in os.walk(pname):
             for ff in f:
-                if 'structure.oebin' in ff:
-                    self.filename = os.path.join(d, "structure.oebin")
-        if self.filename is not None:
-            import json
-            with open(self.filename, 'r') as f:
-                self.data = json.load(f)
-        
+                if "structure.oebin" in ff:
+                    self.filename.append(os.path.join(d, ff))
+                    with open(os.path.join(d, ff), "r") as f:
+                        self.data.append(json.load(f))
+
 
 class Settings(object):
     """
@@ -238,23 +310,35 @@ class Settings(object):
         The pathname to the top-level directory, typically in form
         YYYY-MM-DD_HH-MM-SS
     """
+
     def __init__(self, pname: str):
         self.filename = None
         import os
+
         for d, _, f in os.walk(pname):
             for ff in f:
-                if 'settings.xml' in ff:
+                if "settings.xml" in ff:
                     self.filename = os.path.join(d, "settings.xml")
         self.tree = None
         """
         It's not uncommon to have > 1 of the same type of processor, i.e.
         2 x bandpass filter to look at LFP and APs. This deals with that...
         """
+        self.possible_processors = OrderedDict([
+            ("Pos Tracker", PosTracker()),
+            ("Rhythm FPGA", RhythmFPGA()),
+            ("Neuropix-PXI", NeuropixPXI()),
+            ("Acquisition Board", AcquisitionBoard()),
+            ("Spike Sorter", SpikeSorter()),
+            ("TrackMe", TrackMe()),
+            ("Record Node", RecordNode())
+        ])
         self.processors = OrderedDict()
-        self.electrodes = OrderedDict()
+        self.record_nodes = OrderedDict()
         self.tracker_params = {}
         self.stimcontrol_params = {}
-        self.bandpass_params = OrderedDict()
+        self.load()
+        self.parse()
 
     def load(self):
         """
@@ -265,7 +349,7 @@ class Settings(object):
 
     def parse(self):
         """
-        Parses the basic information about the processors in the 
+        Parses the basic information about the processors in the
         open-ephys signal chain and as described in the settings.xml
         file(s)
         """
@@ -273,63 +357,18 @@ class Settings(object):
             self.load()
         # quick hack to deal with flat binary format that has no settings.xml
         if self.tree is not None:
-            for elem in self.tree.iter('PROCESSOR'):
-                this_proc = elem.get('name')
-                if this_proc == 'Sources/Pos Tracker':
-                    pos_tracker = PosTracker()
-                    recurseNode(elem, addValuesToDataClass, pos_tracker)
-                    self.processors[this_proc] = pos_tracker
-                if this_proc == 'Sources/Rhythm FPGA':
-                    fpga = RhythmFPGA()
-                    recurseNode(elem, addValuesToDataClass, fpga)
-                    self.processors[this_proc] = fpga
-                if this_proc == 'Sources/Neuropix-PXI':
-                    npx = NeuropixPXI()
-                    recurseNode(elem, addValuesToDataClass, npx)
-                    self.processors[this_proc] = npx
-                if this_proc == 'Filters/Spike Sorter':
-                    spike_sorter = SpikeSorter()
-                    recurseNode(elem, addValuesToDataClass, spike_sorter)
-                
-
-    # def parseSpikeSorter(self):
-    #     """
-    #     Parses data attached to each ELECTRODE object in the xml tree
-    #     """
-    #     if len(self.processors) == 0:
-    #         self.parse()
-    #     electrode_info = OrderedDict()
-    #     for child in self.processors['Filters/Spike Sorter'][0].iter():
-    #         if 'SpikeSorter' in child.tag:
-    #             for grandchild in child.iter():
-    #                 if 'ELECTRODE' == grandchild.tag:
-    #                     for this_electrode in grandchild.iter('ELECTRODE'):
-    #                         info_obj = Electrode()
-    #                         info_obj.name = this_electrode.get('name')
-    #                         info_obj.nChannels = this_electrode.get(
-    #                             'numChannels')
-    #                         info_obj.prePeakSamples = this_electrode.get(
-    #                             'prePeakSamples')
-    #                         info_obj.postPeakSamples = this_electrode.get
-    #                         ('postPeakSamples')
-    #                         info_obj.id = this_electrode.get('electrodeID')
-    #                         subchan = []
-    #                         subchanThresh = []
-    #                         subchanActive = []
-    #                         for ggrandkid in grandchild.iter():
-    #                             if 'SUBCHANNEL' == ggrandkid.tag:
-    #                                 for schan in ggrandkid.iter('SUBCHANNEL'):
-    #                                     subchan.append(schan.get('ch'))
-    #                                     subchanThresh.append(
-    #                                         schan.get('thresh'))
-    #                                     subchanActive.append(
-    #                                         schan.get('isActive'))
-
-    #                         info_obj.subChannels = subchan
-    #                         info_obj.subChannelsThresh = subchanThresh
-    #                         info_obj.subChannelsActive = subchanActive
-    #                         electrode_info[info_obj.id] = info_obj
-    #     self.electrodes = electrode_info
+            for elem in self.tree.iter("PROCESSOR"):
+                i_proc = elem.get("name")
+                if i_proc == "Record Node":  # special as could be > 1
+                    recNode = RecordNode()
+                    recurseNode(elem, addValues2Class, recNode)
+                    self.record_nodes[i_proc + " " + recNode.nodeId] = recNode
+                elif i_proc in self.possible_processors.keys():
+                    self.processors[i_proc] = self.possible_processors[i_proc]
+                    recurseNode(elem, addValues2Class, self.processors[i_proc])
+                else:
+                    self.processors[i_proc] = OEPlugin()
+                    recurseNode(elem, addValues2Class, self.processors[i_proc])
 
     def parseStimControl(self):
         """
@@ -337,38 +376,11 @@ class Settings(object):
         """
         if len(self.processors) == 0:
             self.parse()
-        children = self.processors['Sinks/StimControl'][0].iter()
+        children = self.processors["StimControl"][0].iter()
         for child in children:
-            if 'Parameters' in child.tag:
+            if "Parameters" in child.tag:
                 self.stimcontrol_params = child.attrib
         # convert string values to ints
         self.stimcontrol_params = dict(
-            [k, int(v)] for k, v in self.stimcontrol_params.items())
-
-    
-
-    # def parseBandpassFilters(self):
-    #     """
-    #     Parse the bandpass filter information
-    #     """
-    #     if len(self.processors) == 0:
-    #         self.parse()
-    #     bandpass_info = OrderedDict()
-    #     for bpf in self.processors['Filters/Bandpass Filter']:
-    #         if 'PROCESSOR' in bpf.tag:
-    #             this_bpf = BandpassFilter()
-    #             this_bpf.nodeId = bpf.get('NodeId')
-    #             channels = []
-    #             for child in bpf.iter('CHANNEL'):
-    #                 this_chan = ChannelInfo()
-    #                 this_chan.number = child.get('number')
-    #                 this_chan.name = child.get('name')
-    #                 for state in child.iter('SELECTIONSTATE'):
-    #                     this_chan.param = state.get('param')
-    #                     this_chan.record = state.get('record')
-    #                 for params in child.iter('PARAMETERS'):
-    #                     this_chan.lowcut = params.get('lowcut')
-    #                     this_chan.highcut = params.get('highcut')
-    #                 channels.append(this_chan)
-    #                 bandpass_info[this_bpf.nodeId] = channels
-    #     self.bandpass_params = bandpass_info
+            [k, int(v)] for k, v in self.stimcontrol_params.items()
+        )
