@@ -1,13 +1,15 @@
-import matplotlib.pylab as plt
-import matplotlib
-import numpy as np
 import functools
-from ephysiopy.common.binning import RateMap
-from ephysiopy.common.spikecalcs import SpikeCalcsGeneric
-from ephysiopy.dacq2py import tintcolours as tcols
-from mpl_toolkits.axes_grid1 import make_axes_locatable
+
+import matplotlib
+import matplotlib.pylab as plt
 import matplotlib.transforms as transforms
+import numpy as np
 from matplotlib.patches import Rectangle
+from mpl_toolkits.axes_grid1 import make_axes_locatable
+
+from ephysiopy.axona import tintcolours as tcols
+from ephysiopy.common.binning import RateMap, VariableToBin
+from ephysiopy.common.spikecalcs import SpikeCalcsGeneric
 
 
 # Decorators
@@ -30,42 +32,44 @@ def stripAxes(func):
     return wrapper
 
 
+jet_cmap = matplotlib.cm.get_cmap("jet")
+grey_cmap = matplotlib.cm.get_cmap("gray_r")
+
+
 class FigureMaker(object):
     '''
-    A mixin class for dacq2py_util and OEKiloPhy that deals solely with
+    A mixin class for TrialInterface that deals solely with
     producing graphical output
     '''
     def __init__(self):
-        self.data_loaded = False
+        self.PosCalcs = None
 
     def initialise(self):
-        xy = getattr(self, 'xy', None)
-        self.npos = xy.shape[1]
-        hdir = getattr(self, 'dir', None)
-        speed = getattr(self, 'speed', None)
+        xy = getattr(self.PosCalcs, "xy")
+        hdir = getattr(self.PosCalcs, "dir")
+        speed = getattr(self.PosCalcs, "speed")
+        ppm = getattr(self.PosCalcs, "ppm")
+        cmsPerBin = getattr(self.PosCalcs, "cmsPerBin", 3)
+        setattr(self, "npos", xy.shape[1])
         pos_weights = None
         if hdir is not None:
             if np.ma.is_masked(hdir):
                 pos_weights = np.array(~hdir.mask).astype(int)
             else:
                 pos_weights = np.ones_like(hdir)
-        ppm = getattr(self, 'ppm', 300)
-        cmsPerBin = getattr(self, 'cmsPerBin', 3)
-
-        self.RateMapMaker = RateMap(
+        self.RateMap = RateMap(
             xy=xy, hdir=hdir, speed=speed, pos_weights=pos_weights, ppm=ppm,
-            xyInCms=True, cmsPerBin=cmsPerBin)
-        self.RateMapMaker.x_lims = getattr(self, 'x_lims', None)  # 2-tuple
-        self.RateMapMaker.y_lims = getattr(self, 'y_lims', None)
-        self.data_loaded = True
+            xyInCms=True, binsize=cmsPerBin)
+        self.RateMap.x_lims = getattr(self, 'x_lims', None)  # 2-tuple
+        self.RateMap.y_lims = getattr(self, 'y_lims', None)
 
-    def getSpikePosIndices(self, spk_times: np.array):
-        pos_times = getattr(self, 'xyTS')
+    def getSpikePosIndices(self, spk_times: np.ndarray):
+        pos_times = getattr(self.PosCalcs, 'xyTS')
         idx = np.searchsorted(pos_times, spk_times)
         idx[idx == len(pos_times)] = idx[idx == len(pos_times)] - 1
         return idx
 
-    def makeSummaryPlot(self, spk_times: np.array):
+    def makeSummaryPlot(self, spk_times: np.ndarray):
         fig = plt.figure()
         ax = plt.subplot(221)
         self.makeSpikePathPlot(spk_times, ax=ax, markersize=2)
@@ -81,30 +85,32 @@ class FigureMaker(object):
         return fig
 
     @stripAxes
-    def makeRateMap(self, spk_times: np.array,
+    def makeRateMap(self, spk_times: np.ndarray,
                     ax: matplotlib.axes = None) -> matplotlib.axes:
-        self.initialise()
+        if not self.RateMap:
+            self.initialise()
         spk_times_in_pos_samples = self.getSpikePosIndices(spk_times)
         spk_weights = np.bincount(
             spk_times_in_pos_samples, minlength=self.npos)
-        rmap = self.RateMapMaker.getMap(spk_weights)
+        rmap = self.RateMap.getMap(spk_weights)
         ratemap = np.ma.MaskedArray(rmap[0], np.isnan(rmap[0]), copy=True)
-        x, y = np.meshgrid(rmap[1][1][0:-1], rmap[1][0][0:-1])
+        x, y = np.meshgrid(rmap[1][1][0:-1].data, rmap[1][0][0:-1].data)
         vmax = np.nanmax(np.ravel(ratemap))
         if ax is None:
             fig = plt.figure()
             ax = fig.add_subplot(111)
         ax.pcolormesh(
-            x, y, ratemap, cmap=plt.cm.get_cmap("jet"), edgecolors='face',
+            x, y, ratemap, cmap=jet_cmap, edgecolors='face',
             vmax=vmax, shading='auto')
         ax.set_aspect('equal')
         return ax
 
     @stripAxes
-    def makeSpikePathPlot(self, spk_times: np.array = None,
+    def makeSpikePathPlot(self, spk_times: np.ndarray = None,
                           ax: matplotlib.axes = None,
                           **kwargs) -> matplotlib.axes:
-        self.initialise()
+        if not self.RateMap:
+            self.initialise()
         if 'c' in kwargs:
             col = kwargs.pop('c')
         else:
@@ -112,26 +118,28 @@ class FigureMaker(object):
         if ax is None:
             fig = plt.figure()
             ax = fig.add_subplot(111)
-        ax.plot(self.xy[0, :], self.xy[1, :], c=tcols.colours[0], zorder=1)
+        ax.plot(self.PosCalcs.xy[0, :],
+                self.PosCalcs.xy[1, :], c=tcols.colours[0], zorder=1)
         ax.set_aspect('equal')
         if spk_times is not None:
             idx = self.getSpikePosIndices(spk_times)
-            ax.plot(
-                self.xy[0, idx], self.xy[1, idx], 's', c=col, **kwargs)
+            ax.plot(self.PosCalcs.xy[0, idx],
+                    self.PosCalcs.xy[1, idx], 's', c=col, **kwargs)
         return ax
 
     @stripAxes
     def makeSAC(self, spk_times: np.array = None,
                 ax: matplotlib.axes = None, **kwargs) -> matplotlib.axes:
-        self.initialise()
+        if not self.RateMap:
+            self.initialise()
         spk_times_in_pos_samples = self.getSpikePosIndices(spk_times)
         spk_weights = np.bincount(
             spk_times_in_pos_samples, minlength=self.npos)
-        rmap = self.RateMapMaker.getMap(spk_weights)
-        from ephysiopy.common import gridcell
-        S = gridcell.SAC()
+        rmap = self.RateMap.getMap(spk_weights)
         nodwell = ~np.isfinite(rmap[0])
-        sac = S.autoCorr2D(rmap[0], nodwell)
+        sac = self.RateMap.autoCorr2D(rmap[0], nodwell)
+        from ephysiopy.common.gridcell import SAC
+        S = SAC()
         measures = S.getMeasures(sac)
         if ax is None:
             fig = plt.figure()
@@ -142,11 +150,12 @@ class FigureMaker(object):
     @stripAxes
     def makeHDPlot(self, spk_times: np.array = None,
                    ax: matplotlib.axes = None, **kwargs) -> matplotlib.axes:
-        self.initialise()
+        if not self.RateMap:
+            self.initialise()
         spk_times_in_pos_samples = self.getSpikePosIndices(spk_times)
         spk_weights = np.bincount(
             spk_times_in_pos_samples, minlength=self.npos)
-        rmap = self.RateMapMaker.getMap(spk_weights, 'dir')
+        rmap = self.RateMap.getMap(spk_weights, varType=VariableToBin.DIR)
         if ax is None:
             fig = plt.figure()
             ax = fig.add_subplot(111, projection='polar')
@@ -154,7 +163,7 @@ class FigureMaker(object):
         # is not polar. deal with polar first
         theta = np.deg2rad(rmap[1][0])
         ax.clear()
-        r = rmap[0]
+        r = rmap[0]  # in samples so * pos sample_rate
         r = np.insert(r, -1, r[0])
         if 'polar' in ax.name:
             ax.plot(theta, r)
@@ -167,14 +176,14 @@ class FigureMaker(object):
         # See if we should add the mean resultant vector (mrv)
         if 'add_mrv' in kwargs:
             from ephysiopy.common.statscalcs import mean_resultant_vector
-            angles = self.dir[spk_times_in_pos_samples]
+            angles = self.PosCalcs.dir[spk_times_in_pos_samples]
             r, th = mean_resultant_vector(np.deg2rad(angles))
             ax.plot([th, th], [0, r*np.max(rmap[0])], 'r')
         if 'polar' in ax.name:
             ax.set_thetagrids([0, 90, 180, 270])
         return ax
 
-    @stripAxes
+    # @stripAxes
     def makeSpeedVsRatePlot(
             self, spk_times: np.array, minSpeed: float = 0.0,
             maxSpeed: float = 40.0, sigma: float = 3.0,
@@ -188,7 +197,7 @@ class FigureMaker(object):
         self.initialise()
         spk_times_in_pos_samples = self.getSpikePosIndices(spk_times)
 
-        speed = np.ravel(self.speed)
+        speed = np.ravel(self.PosCalcs.speed)
         if np.nanmax(speed) < maxSpeed:
             maxSpeed = np.nanmax(speed)
         spd_bins = np.arange(minSpeed, maxSpeed, 1.0)
@@ -200,7 +209,8 @@ class FigureMaker(object):
 
         x1 = spk_times_in_pos_samples
         S = SpikeCalcsGeneric(x1)
-        spk_sm = S.smoothSpikePosCount(x1, self.xyTS.shape[0], sigma, None)
+        spk_sm = S.smoothSpikePosCount(
+            x1, self.PosCalcs.xyTS.shape[0], sigma, None)
         spk_sm = np.ma.MaskedArray(spk_sm, mask=np.ma.getmask(speed_filt))
         spd_dig = np.digitize(speed_filt, spd_bins, right=True)
         mn_rate = np.array([np.ma.mean(
@@ -212,32 +222,33 @@ class FigureMaker(object):
         fig = plt.figure()
         ax = fig.add_subplot(111)
         ax.errorbar(
-            spd_bins, mn_rate * self.pos_sample_rate,
+            spd_bins, mn_rate * self.PosCalcs.sample_rate,
             yerr=var, color='k')
         ax.set_xlim(spd_bins[0], spd_bins[-1])
         plt.xticks([spd_bins[0], spd_bins[-1]], ['0', '{:.2g}'.format(
             spd_bins[-1])], fontweight='normal', size=6)
         plt.yticks([0, np.nanmax(
-            mn_rate)*self.pos_sample_rate], ['0', '{:.2f}'.format(
+            mn_rate)*self.PosCalcs.sample_rate], ['0', '{:.2f}'.format(
                 np.nanmax(mn_rate))], fontweight='normal', size=6)
         return ax
 
-    @stripAxes
+    # @stripAxes
     def makeSpeedVsHeadDirectionPlot(self, spk_times: np.array,
                                      ax: matplotlib.axes = None,
                                      **kwargs) -> matplotlib.axes:
         self.initialise()
         spk_times_in_pos_samples = self.getSpikePosIndices(spk_times)
         idx = np.array(spk_times_in_pos_samples, dtype=int)
-        if np.ma.is_masked(self.speed):
+        if np.ma.is_masked(self.PosCalcs.speed):
             w = self.speed.mask
             w = np.array(~w, dtype=int)
         else:
-            w = np.bincount(idx, minlength=self.speed.shape[0])
+            w = np.bincount(idx, minlength=self.PosCalcs.speed.shape[0])
         dir_bins = np.arange(0, 360, 6)
         spd_bins = np.arange(0, 30, 1)
-        h = np.histogram2d(
-            self.dir, self.speed, [dir_bins, spd_bins], weights=w)
+        h = np.histogram2d(self.PosCalcs.dir,
+                           self.PosCalcs.speed,
+                           [dir_bins, spd_bins], weights=w)
         from ephysiopy.common.utils import blurImage
         im = blurImage(h[0], 5, ftype='gaussian')
         im = np.ma.MaskedArray(im)
@@ -249,11 +260,12 @@ class FigureMaker(object):
         if ax is None:
             fig = plt.figure()
             ax = fig.add_subplot(111)
-        ax.pcolormesh(x, y, im.T, cmap=plt.cm.get_cmap("jet"),
+        ax.pcolormesh(x, y, im.T, cmap=jet_cmap,
                       edgecolors='face',
                       vmax=vmax, shading='auto')
         plt.xticks([90, 180, 270], fontweight='normal', size=6)
         plt.yticks([10, 20], fontweight='normal', size=6)
+        plt.xlabel("Heading", fontweight='normal', size=6)
         return ax
 
     def makePowerSpectrum(
@@ -505,10 +517,10 @@ class FigureMaker(object):
             np.arange(0, np.shape(A)[0]))
         vmax = np.nanmax(np.ravel(A))
         ax.pcolormesh(
-            x, y, A, cmap=plt.cm.get_cmap("gray_r"),
+            x, y, A, cmap=grey_cmap,
             edgecolors='face', vmax=vmax, shading='auto')
         import copy
-        cmap = copy.copy(plt.cm.get_cmap("jet"))
+        cmap = copy.copy(jet_cmap)
         cmap.set_bad('w', 0)
         ax.pcolormesh(
             x, y, Am, cmap=cmap,
@@ -530,13 +542,161 @@ class FigureMaker(object):
             if p[0] <= inDict['dist_to_centre'].shape[0] / 2:
                 ax.plot(
                     (inDict['dist_to_centre'].shape[1]/2, p[1]),
-                    (inDict['dist_to_centre'].shape[0] / 2, p[0]), 'k', **kwargs)
+                    (inDict['dist_to_centre'].shape[0] / 2, p[0]), 'k',
+                    **kwargs)
         ax.invert_yaxis()
         all_ax = ax.axes
         all_ax.set_aspect('equal')
         all_ax.set_xlim((0.5, inDict['dist_to_centre'].shape[1]-1.5))
         all_ax.set_ylim((inDict['dist_to_centre'].shape[0]-.5, -.5))
         return ax
+
+    def plotSpectrogramByDepth(self,
+                               nchannels: int = 384,
+                               nseconds: int = 100,
+                               maxFreq: int = 125,
+                               channels: list = [],
+                               frequencies: list = [],
+                               frequencyIncrement: int = 1,
+                               **kwargs):
+        """
+        Plots a heat map spectrogram of the LFP for each channel.
+        Line plots of power per frequency band and power on a subset of
+        channels are also displayed to the right and above the main plot.
+        Parameters
+        ----------
+        nchannels : int
+            The number of channels on the probe
+        nseconds : int, optional
+            How long in seconds from the start of the trial to do
+            the spectrogram for (for speed).
+            Default 100
+        maxFreq : int
+            The maximum frequency in Hz to plot the spectrogram out to.
+            Maximum 1250. Default 125
+        channels: list
+            The channels to plot separately on the top plot
+        frequencies: list
+            The specific frequencies to examine across
+            all channels. The mean from frequency: frequency+frequencyIncrement
+            is calculated and plotted on the left hand side of the plot
+        frequencyIncrement: int
+            The amount to add to each value of the frequencies list above
+        kwargs: valid key value pairs:
+            "saveas" - save the figure to this location, needs absolute
+            path and filename
+
+        Notes
+        -----
+        Should also allow kwargs to specify exactly which channels
+        and / or frequency bands to do the line plots for
+        """
+        if not self.path2LFPdata:
+            raise TypeError("Not a probe recording so not plotting")
+        import os
+        lfp_file = os.path.join(self.path2LFPdata, 'continuous.dat')
+        status = os.stat(lfp_file)
+        nsamples = int(status.st_size / 2 / nchannels)
+        mmap = np.memmap(lfp_file,
+                         np.int16,
+                         'r',
+                         0,
+                         (nchannels, nsamples),
+                         order='F')
+        # Load the channel map NB assumes this is in the AP data
+        # location and that kilosort was run there
+        channel_map = np.squeeze(
+            np.load(os.path.join(self.path2APdata, 'channel_map.npy')))
+        lfp_sample_rate = 2500
+        data = np.array(mmap[channel_map, 0:nseconds*lfp_sample_rate])
+        from ephysiopy.common.ephys_generic import EEGCalcsGeneric
+        E = EEGCalcsGeneric(data[0, :], lfp_sample_rate)
+        E.calcEEGPowerSpectrum()
+        spec_data = np.zeros(shape=(data.shape[0], len(E.sm_power[0::50])))
+        for chan in range(data.shape[0]):
+            E = EEGCalcsGeneric(data[chan, :], lfp_sample_rate)
+            E.calcEEGPowerSpectrum()
+            spec_data[chan, :] = E.sm_power[0::50]
+
+        x, y = np.meshgrid(E.freqs[0::50], channel_map)
+        import matplotlib.colors as colors
+        from matplotlib.pyplot import cm
+        from mpl_toolkits.axes_grid1 import make_axes_locatable
+        _, spectoAx = plt.subplots()
+        spectoAx.pcolormesh(x,
+                            y,
+                            spec_data,
+                            edgecolors='face',
+                            cmap='bone',
+                            norm=colors.LogNorm())
+        spectoAx.set_xlim(0, maxFreq)
+        spectoAx.set_ylim(channel_map[0], channel_map[-1])
+        spectoAx.set_xlabel('Frequency (Hz)')
+        spectoAx.set_ylabel('Channel')
+        divider = make_axes_locatable(spectoAx)
+        channel_spectoAx = divider.append_axes("top",
+                                               1.2,
+                                               pad=0.1,
+                                               sharex=spectoAx)
+        meanfreq_powerAx = divider.append_axes("right",
+                                               1.2,
+                                               pad=0.1,
+                                               sharey=spectoAx)
+        plt.setp(channel_spectoAx.get_xticklabels() +
+                 meanfreq_powerAx.get_yticklabels(), visible=False)
+
+        # plot mean power across some channels
+        mn_power = np.mean(spec_data, 0)
+        if not channels:
+            channels = range(1, nchannels, 60)
+        cols = iter(cm.rainbow(np.linspace(0, 1, len(channels))))
+        for chan in channels:
+            c = next(cols)
+            channel_spectoAx.plot(E.freqs[0::50],
+                                  10*np.log10(spec_data[chan, :]/mn_power),
+                                  c=c,
+                                  label=str(chan))
+
+        channel_spectoAx.set_ylabel('Channel power(dB)')
+        channel_spectoAx.legend(bbox_to_anchor=(0., 1.02, 1., .102),
+                                loc='lower left',
+                                mode='expand',
+                                fontsize='x-small',
+                                ncol=4)
+
+        # plot mean frequencies across all channels
+        if not frequencyIncrement:
+            freq_inc = 6
+        else:
+            freq_inc = frequencyIncrement
+        if not frequencies:
+            lower_freqs = np.arange(1, maxFreq-freq_inc, freq_inc)
+        else:
+            lower_freqs = frequencies
+        upper_freqs = [f + freq_inc for f in lower_freqs]
+        cols = iter(cm.nipy_spectral(np.linspace(0, 1, len(upper_freqs))))
+        mn_power = np.mean(spec_data, 1)
+        for freqs in zip(lower_freqs, upper_freqs):
+            freq_mask = np.logical_and(
+                E.freqs[0::50] > freqs[0], E.freqs[0::50] < freqs[1])
+            mean_power = 10*np.log10(
+                np.mean(spec_data[:, freq_mask], 1) / mn_power)
+            c = next(cols)
+            meanfreq_powerAx.plot(mean_power,
+                                  channel_map,
+                                  c=c,
+                                  label=str(freqs[0]) + " - " + str(freqs[1]))
+        meanfreq_powerAx.set_xlabel('Mean freq. band power(dB)')
+        meanfreq_powerAx.legend(bbox_to_anchor=(0., 1.02, 1., .102),
+                                loc='lower left',
+                                mode='expand',
+                                fontsize='x-small',
+                                ncol=1)
+        if 'saveas' in kwargs:
+            saveas = kwargs['saveas']
+            plt.savefig(saveas)
+        plt.show()
+
     '''
     def plotDirFilteredRmaps(self, tetrode, cluster, maptype='rmap', **kwargs):
         """
